pub struct DependencyGraph {
pub root: PathBuf,
pub order: Vec<PathBuf>,
pub files: HashMap<PathBuf, FileNode>,
pub datasource_declarations: HashMap<String, PathBuf>,
pub datasource_updaters: HashMap<String, Vec<PathBuf>>,
pub warnings: Vec<String>,
}Expand description
Result of dependency resolution
Fields
root: PathBufRoot file that was analyzed
order: Vec<PathBuf>All files in dependency order (dependencies come before dependents)
files: HashMap<PathBuf, FileNode>Detailed information about each file
datasource_declarations: HashMap<String, PathBuf>Mapping of datasource names to the file that declares them
datasource_updaters: HashMap<String, Vec<PathBuf>>Mapping of datasource names to files that update them (via persist)
warnings: Vec<String>Any errors encountered (non-fatal)